==> v1.0.0.20180119_beta.zip: fastadmin/application/index/lang/zh-cn/user.php <==
<?php

return [
    'User center'                           => '会员中心',
    'Register'                              => '注册',
    'Login'                                 => '登录',
    'Account'                               => '账号',
    'Mobile'                                => '手机号',
    'Email'                                 => '邮箱',
    'Captcha'                               => '验证码',
    'Lv'                                    => 'Lv',
    'Score'                                 => '积分',
    'Day'                                   => '天',
    'Intro'                                 => '个人介绍',
    'Successions'                           => '连续登录',
    'Maxsuccessions'                        => '最长连续登录',
    'Logintime'                             => '登录时间',
    'Prevtime'                              => '最后登录',
    'Change'                                => '修改',
    'Click to edit'                         => '点击编辑',
    'Email/Mobile/Username'                 => '邮箱/手机/用户名',
    'Sign up successful'                    => '注册成功',
    'Email active successful'               => '邮箱激活成功',
    'Username can not be empty'             => '用户名不能为空',
    'Username must be 6 to 30 characters'   => '用户名必须6-30个字符',
    'Password can not be empty'             => '密码不能为空',
    'Password must be 6 to 30 characters'   => '密码必须6-30个字符',
    'Email is incorrect'                    => '邮箱格式不正确',
    'Mobile is incorrect'                   => '手机格式不正确',
    'Username already exist'                => '用户名已经存在',
    'Email already exist'                   => '邮箱已经存在',
    'Mobile already exist'                  => '手机号已经存在',
    'Username is incorrect'                 => '用户名不正确',
    'Email is incorrect'                    => '邮箱不正确',
    'Account is locked'                     => '账户已经被锁定',
    'Password is incorrect'                 => '密码不正确',
    'Account is incorrect'                  => '账户不正确',
    'Account not exist'                     => '账户不存在',
    'Account can not be empty'              => '账户不能为空',
    'Username or password is incorrect'     => '用户名或密码不正确',
    'You are not logged in'                 => '你当前还未登录',
    'You\'ve logged in, do not login again' => '你已经存在，请不要重复登录',
    'Profile'                               => '个人资料',
    'Old password'                          => '旧密码',
    'New password'                          => '新密码',
    'Renew password'                        => '确认新密码',
    'Change password'                       => '修改密码',
    'New email'                             => '新邮箱',
    'New mobile'                            => '新手机号',
    'Change password successful'            => '修改密码成功',
    'Captcha is incorrect'                  => '验证码不正确',
    'Sign up successful'                    => '注册成功',
    'Logged in successful'                  => '登录成功',
    'Logout successful'                     => '注销成功',
    'Operation failed'                      => '操作失败',
    'Invalid parameters'                    => '参数不正确',
    'Change password failure'               => '修改密码失败',
    'Change password successful'            => '修改密码成功',
];

==> v1.0.0.20180310_beta.zip: fastadmin/application/index/lang/zh-cn/user.php <==
<?php

return [
    'User center'                           => '会员中心',
    'Register'                              => '注册',
    'Login'                                 => '登录',
    'Account'                               => '账号',
    'Mobile'                                => '手机号',
    'Email'                                 => '邮箱',
    'Captcha'                               => '验证码',
    'Lv'                                    => 'Lv',
    'Score'                                 => '积分',
    'Day'                                   => '天',
    'Intro'                                 => '个人介绍',
    'Successions'                           => '连续登录',
    'Maxsuccessions'                        => '最长连续登录',
    'Logintime'                             => '登录时间',
    'Prevtime'                              => '最后登录',
    'Change'                                => '修改',
    'Click to edit'                         => '点击编辑',
    'Email/Mobile/Username'                 => '邮箱/手机/用户名',
    'Sign up successful'                    => '注册成功',
    'Email active successful'               => '邮箱激活成功',
    'Username can not be empty'             => '用户名不能为空',
    'Username must be 3 to 30 characters'   => '用户名必须3-30个字符',
    'Account must be 3 to 50 characters'    => '账户必须3-50个字符',
    'Password can not be empty'             => '密码不能为空',
    'Password must be 6 to 30 characters'   => '密码必须6-30个字符',
    'Email is incorrect'                    => '邮箱格式不正确',
    'Mobile is incorrect'                   => '手机格式不正确',
    'Username already exist'                => '用户名已经存在',
    'Email already exist'                   => '邮箱已经存在',
    'Mobile already exist'                  => '手机号已经存在',
    'Username is incorrect'                 => '用户名不正确',
    'Email is incorrect'                    => '邮箱不正确',
    'Account is locked'                     => '账户已经被锁定',
    'Password is incorrect'                 => '密码不正确',
    'Account is incorrect'                  => '账户不正确',
    'Account not exist'                     => '账户不存在',
    'Account can not be empty'              => '账户不能为空',
    'Username or password is incorrect'     => '用户名或密码不正确',
    'You are not logged in'                 => '你当前还未登录',
    'You\'ve logged in, do not login again' => '你已经登录,请不要重复登录',
    'Profile'                               => '个人资料',
    'Old password'                          => '旧密码',
    'New password'                          => '新密码',
    'Renew password'                        => '确认新密码',
    'Change password'                       => '修改密码',
    'New email'                             => '新邮箱',
    'New mobile'                            => '新手机号',
    'Change password successful'            => '修改密码成功',
    'Captcha is incorrect'                  => '验证码不正确',
    'Sign up successful'                    => '注册成功',
    'Logged in successful'                  => '登录成功',
    'Logout successful'                     => '注销成功',
    'Operation failed'                      => '操作失败',
    'Invalid parameters'                    => '参数不正确',
    'Change password failure'               => '修改密码失败',
    'Change password successful'            => '修改密码成功',
];
